"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Logger = void 0;
const winston_1 = __importDefault(require("winston"));
const elastic_1 = require("./elastic");
const console_1 = require("./console");
/**
 * Logger class
 */
class Logger {
    constructor(options) {
        this.winston = winston_1.default;
        if (options.elastic && options.elastic.enabled) {
            const elasticTransport = new elastic_1.ElasticLogger(options.elastic.host, options.elastic.log);
            this.winston.add(elasticTransport.getTransport(options.elastic.indexPrefix, options.elastic.level));
        }
        if (options.console && options.console.enabled) {
            const consoleTransport = new console_1.ConsoleLogger(options.console.level);
            this.winston.add(consoleTransport.getTransport());
        }
    }
    /**
     * Construct Message
     * @param message
     * @param logId
     */
    constructMessage(message, logId) {
        return message ? `${message} | ${logId}` : `${logId}`;
    }
    /**
     * Silly logger level, for silly logs
     *
     * @param message
     * @param meta
     */
    // eslint-disable-next-line @typescript-eslint/ban-types
    silly(message, logId, meta) {
        try {
            winston_1.default.silly(this.constructMessage(message, logId), { logId, ...meta });
        }
        catch (error) {
            console.log(error.message);
        }
    }
    /**
     * Debug logger level, for application development logs
     *
     * @param message
     * @param meta
     */
    // eslint-disable-next-line @typescript-eslint/ban-types
    debug(message, logId, meta) {
        try {
            winston_1.default.debug(this.constructMessage(message, logId), { logId, ...meta });
        }
        catch (error) {
            console.log(error.message);
        }
    }
    /**
     * Verbose logger level, for application rules debug logs
     *
     * @param message
     * @param meta
     */
    // eslint-disable-next-line @typescript-eslint/ban-types
    verbose(message, logId, meta) {
        try {
            winston_1.default.verbose(this.constructMessage(message, logId), { logId, ...meta });
        }
        catch (error) {
            console.log(error.message);
        }
    }
    /**
     * Info logger level, for application rules logs
     *
     * @param message
     * @param meta
     */
    // eslint-disable-next-line @typescript-eslint/ban-types
    info(message, logId, meta) {
        try {
            winston_1.default.info(this.constructMessage(message, logId), { logId, ...meta });
        }
        catch (error) {
            console.log(error.message);
        }
    }
    /**
     * Warn logger level, for application rules exceptions logs
     *
     * @param message
     * @param meta
     */
    // eslint-disable-next-line @typescript-eslint/ban-types
    warn(message, logId, meta) {
        try {
            winston_1.default.warn(this.constructMessage(message, logId), { logId, ...meta });
        }
        catch (error) {
            console.log(error.message);
        }
    }
    /**
     * Error logger level, for application rules error
     *
     * @param message
     * @param meta
     */
    // eslint-disable-next-line @typescript-eslint/ban-types
    error(message, logId, meta) {
        try {
            winston_1.default.error(this.constructMessage(message, logId), { logId, ...meta });
        }
        catch (error) {
            console.log(error.message);
        }
    }
}
exports.Logger = Logger;
//# sourceMappingURL=index.js.map