"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.shutdown = void 0;
const index_1 = require("./index");
/**
 * Bind the gracefull shutdown to the application
 * @param server
 * @param database
 * @param tasks
 */
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
exports.shutdown = async (server, database, tasks) => {
    const closeServer = () => {
        return new Promise((resolve, reject) => {
            // Close server
            console.log('[Server] Closing...');
            server.listen.close(() => {
                console.log('[Server] Closed!');
                resolve();
            });
        });
    };
    const closeDatabase = () => {
        return new Promise((resolve, reject) => {
            console.log('[Database] Closing...');
            const { cron } = database.models;
            if (cron) {
                cron.updateMany({}, { running: false }).then(value => {
                    console.log('[Database] crons set running = false');
                    database.connection.close(false, () => {
                        console.log('[Database] Closed!');
                        resolve();
                    });
                });
            }
            else {
                database.connection.close(false, () => {
                    console.log('[Database] Closed!');
                    resolve();
                });
            }
        });
    };
    const closeTasks = () => {
        return new Promise((resolve, reject) => {
            console.log('[Tasks] Stopping and closing tasks...');
            // Close the channel so we won't recieve any more tasks
            index_1.counter.consumerTags.forEach(async ({ consumerTag, ch }) => {
                await ch.cancel(consumerTag);
            });
            // Loop interval until all tasks are finished
            const s = setInterval(async () => {
                if (index_1.counter.tasksRunning > 0) {
                    console.log(`[Tasks] Waiting ${index_1.counter.tasksRunning}...`);
                    return;
                }
                // Disable Tasks
                await tasks.con.close();
                console.log('[Tasks] Stopped and connection is closed!');
                resolve(clearInterval(s));
            }, 5000);
        });
    };
    const closeCrons = () => {
        return new Promise((resolve, reject) => {
            console.log('[Routines] stopping routines');
            // Disable Crons
            for (let i = 0; index_1.counter.crons.length > i; i++) {
                const routine = index_1.counter.crons[i];
                if (routine.running) {
                    console.log(routine.runningId, routine.running);
                    continue;
                }
                routine.stop();
            }
            resolve();
            const cronsLoop = () => {
                let cronsRunning = 0;
                // Disable Crons
                for (let i = 0; index_1.counter.crons.length > i; i++) {
                    const routine = index_1.counter.crons[i];
                    if (routine.running) {
                        cronsRunning++;
                        return;
                    }
                    routine.stop();
                }
                if (cronsRunning > 0) {
                    return cronsLoop();
                }
                return resolve();
            };
        });
    };
    const gracefullShutdown = async () => {
        if (server && server.listen)
            await closeServer();
        await closeCrons();
        if (database)
            await closeDatabase();
        if (tasks && tasks.con)
            await closeTasks();
        console.info('Ready to exit');
        // Exit the application
        process.exit(0);
    };
    process.on('SIGTERM', gracefullShutdown);
    process.on('SIGINT', gracefullShutdown);
};
//# sourceMappingURL=shutdown.js.map