"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Tasks = void 0;
const amqplib_1 = __importDefault(require("amqplib"));
const index_1 = require("../index");
class Tasks {
    constructor(options) {
        this.running = 0;
        this.enabled = options.enabled;
        this.host = options.host;
    }
    start() {
        return new Promise((resolve, reject) => {
            if (!this.enabled)
                return resolve();
            try {
                amqplib_1.default.connect(`amqp://${this.host}`).then((con) => {
                    return con.createChannel().then((ch) => {
                        this.ch = ch;
                        this.con = con;
                        return resolve(this);
                    }).catch((ee) => {
                        reject(ee);
                    });
                }).catch((e) => {
                    reject(e);
                });
            }
            catch (e) {
                reject(e);
            }
        });
    }
    /* Send message to exchange abstraction */
    send(exchange, routeKey, message, options = {}) {
        if (!this.enabled)
            throw Error('Tasks feature is not enabled');
        let apmTransaction = null;
        if (index_1.apm)
            apmTransaction = index_1.apm.startTransaction(`${exchange} - ${routeKey}`, 'Rabbit');
        // Check if it's an object, if true convert to json
        const parsedMsg = (typeof message === 'object' && !Array.isArray(message)) ? JSON.stringify(message) : message;
        this.ch.assertExchange(exchange, options.type || 'direct', { durable: true });
        // Sends the message to the queue
        const status = this.ch.publish(exchange, routeKey, Buffer.from(parsedMsg));
        if (apmTransaction)
            apmTransaction.end();
        return status;
    }
}
exports.Tasks = Tasks;
//# sourceMappingURL=index.js.map